==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/SanForCertArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SANs for certificate.
 * @property dns DNS SANs.
 * @property ip IP address SANs.
 */
public data class SanForCertArgs(
    public val dns: Output<List<String>>,
    public val ip: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs.builder()
            .dns(dns.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ip(ip.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SanForCertArgs].
 */
@PulumiTagMarker
public class SanForCertArgsBuilder internal constructor() {
    private var dns: Output<List<String>>? = null

    private var ip: Output<List<String>>? = null

    /**
     * @param value DNS SANs.
     */
    @JvmName("ufbdxgeymhrgemwy")
    public suspend fun dns(`value`: Output<List<String>>) {
        this.dns = value
    }

    @JvmName("cyauieacqylvdjsk")
    public suspend fun dns(vararg values: Output<String>) {
        this.dns = Output.all(values.asList())
    }

    /**
     * @param values DNS SANs.
     */
    @JvmName("jkkffhfeecwqycdj")
    public suspend fun dns(values: List<Output<String>>) {
        this.dns = Output.all(values)
    }

    /**
     * @param value IP address SANs.
     */
    @JvmName("lbqsmgeiavalfmsc")
    public suspend fun ip(`value`: Output<List<String>>) {
        this.ip = value
    }

    @JvmName("xeloobitxhmwdklt")
    public suspend fun ip(vararg values: Output<String>) {
        this.ip = Output.all(values.asList())
    }

    /**
     * @param values IP address SANs.
     */
    @JvmName("hbtxxkodvhyteflq")
    public suspend fun ip(values: List<Output<String>>) {
        this.ip = Output.all(values)
    }

    /**
     * @param value DNS SANs.
     */
    @JvmName("hdverwdsumomwiwf")
    public suspend fun dns(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dns = mapped
    }

    /**
     * @param values DNS SANs.
     */
    @JvmName("nerjhvlwnvpaivar")
    public suspend fun dns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dns = mapped
    }

    /**
     * @param value IP address SANs.
     */
    @JvmName("fvgtmmbuukynuslk")
    public suspend fun ip(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ip = mapped
    }

    /**
     * @param values IP address SANs.
     */
    @JvmName("bjxvodnupvkkoqle")
    public suspend fun ip(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ip = mapped
    }

    internal fun build(): SanForCertArgs = SanForCertArgs(
        dns = dns ?: throw PulumiNullFieldException("dns"),
        ip = ip ?: throw PulumiNullFieldException("ip"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/SanForCertArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SANs for certificate.
 * @property dns DNS SANs.
 * @property ip IP address SANs.
 */
public data class SanForCertArgs(
    public val dns: Output<List<String>>,
    public val ip: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.SanForCertArgs.builder()
            .dns(dns.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ip(ip.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SanForCertArgs].
 */
@PulumiTagMarker
public class SanForCertArgsBuilder internal constructor() {
    private var dns: Output<List<String>>? = null

    private var ip: Output<List<String>>? = null

    /**
     * @param value DNS SANs.
     */
    @JvmName("vcjxvxvjnswebkmt")
    public suspend fun dns(`value`: Output<List<String>>) {
        this.dns = value
    }

    @JvmName("nmgovfgplddeotnr")
    public suspend fun dns(vararg values: Output<String>) {
        this.dns = Output.all(values.asList())
    }

    /**
     * @param values DNS SANs.
     */
    @JvmName("oonheoygjpdgqgdo")
    public suspend fun dns(values: List<Output<String>>) {
        this.dns = Output.all(values)
    }

    /**
     * @param value IP address SANs.
     */
    @JvmName("hbrricaatlgklise")
    public suspend fun ip(`value`: Output<List<String>>) {
        this.ip = value
    }

    @JvmName("ceasmxdqifyckbud")
    public suspend fun ip(vararg values: Output<String>) {
        this.ip = Output.all(values.asList())
    }

    /**
     * @param values IP address SANs.
     */
    @JvmName("ifkmgtdxxrftiakd")
    public suspend fun ip(values: List<Output<String>>) {
        this.ip = Output.all(values)
    }

    /**
     * @param value DNS SANs.
     */
    @JvmName("khilxuhdylbcopcl")
    public suspend fun dns(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dns = mapped
    }

    /**
     * @param values DNS SANs.
     */
    @JvmName("yepaxtjxxtmlggdd")
    public suspend fun dns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dns = mapped
    }

    /**
     * @param value IP address SANs.
     */
    @JvmName("bjpayqfgrgesjotx")
    public suspend fun ip(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ip = mapped
    }

    /**
     * @param values IP address SANs.
     */
    @JvmName("ngjvgjktikchywyd")
    public suspend fun ip(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ip = mapped
    }

    internal fun build(): SanForCertArgs = SanForCertArgs(
        dns = dns ?: throw PulumiNullFieldException("dns"),
        ip = ip ?: throw PulumiNullFieldException("ip"),
    )
}
